@@ -12,8 +12,6 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-
-from django.core.urlresolvers import reverse
 from django.forms import ValidationError
 from django.utils.translation import ugettext_lazy as _
 
@@ -23,8 +21,6 @@ from horizon import messages
 
 from tacker_horizon.openstack_dashboard import api
 
-import yaml
-
 
 class OnBoardVNF(forms.SelfHandlingForm):
     name = forms.CharField(max_length=80, label=_("Name"), required=False)
@@ -52,7 +48,6 @@ class OnBoardVNF(forms.SelfHandlingForm):
                    'data-source-raw': _('TOSCA YAML')}),
         required=False)
 
-
     def __init__(self, request, *args, **kwargs):
         super(OnBoardVNF, self).__init__(request, *args, **kwargs)
 
@@ -75,7 +70,7 @@ class OnBoardVNF(forms.SelfHandlingForm):
                 toscal_str = self.files['toscal_file'].read()
             else:
                 toscal_str = data['direct_input']
-            #toscal = yaml.loads(toscal_str)
+            # toscal = yaml.loads(toscal_str)
             data['tosca'] = toscal_str
         except Exception as e:
             msg = _('There was a problem loading the namespace: %s.') % e
@@ -86,10 +81,11 @@ class OnBoardVNF(forms.SelfHandlingForm):
     def handle(self, request, data):
         try:
             toscal = data['tosca']
-            tosca_arg = { 'vnfd': {'attributes': {'vnfd': toscal}}}
+            tosca_arg = {'vnfd': {'attributes': {'vnfd': toscal}}}
             vnfd_instance = api.tacker.create_vnfd(request, tosca_arg)
             messages.success(request,
-                             _('VNF Catalog entry %s has been created.') % vnfd_instance['vnfd']['name'])
+                             _('VNF Catalog entry %s has been created.') %
+                             vnfd_instance['vnfd']['name'])
             return toscal
         except Exception as e:
             msg = _('Unable to create TOSCA. %s')
