@@ -13,7 +13,6 @@
 # under the License.
 
 import logging
-import yaml
 
 from django.forms import ValidationError
 from django.utils.translation import ugettext_lazy as _
@@ -26,9 +25,12 @@ from tacker_horizon.openstack_dashboard import api
 
 LOG = logging.getLogger(__name__)
 
-class AddService(forms.SelfHandlingForm):
+
+class DeployVNF(forms.SelfHandlingForm):
     vnf_name = forms.CharField(max_length=80, label=_("VNF Name"))
     vnfd_id = forms.ChoiceField(label=_("VNF Catalog Name"))
+    vim_id = forms.ChoiceField(label=_("VIM Name"))
+    region_name = forms.CharField(label=_("Region Name"), required=False)
     source_type = forms.ChoiceField(
         label=_('Parameter Value Source'),
         required=False,
@@ -63,7 +65,8 @@ class AddService(forms.SelfHandlingForm):
 
     config_file = forms.FileField(
         label=_('Configuration Value File'),
-        help_text=_('VNF Configuration file with YAML formatted contents to upload.'),
+        help_text=_('VNF Configuration file with YAML '
+                    'formatted contents to upload.'),
         widget=forms.FileInput(
             attrs={'class': 'switched', 'data-switch-on': 'config',
                    'data-config-file': _('Configuration Value File')}),
@@ -78,21 +81,35 @@ class AddService(forms.SelfHandlingForm):
         required=False)
 
     def __init__(self, request, *args, **kwargs):
-        super(AddService, self).__init__(request, *args, **kwargs)
+        super(DeployVNF, self).__init__(request, *args, **kwargs)
 
         try:
             vnfd_list = api.tacker.vnfd_list(request)
-            available_choices = [(vnf['id'],vnf['name'])
-                                 for vnf in vnfd_list]
+            available_choices_vnfd = [(vnf['id'], vnf['name']) for vnf in
+                                      vnfd_list]
         except Exception as e:
+            available_choices_vnfd = []
             msg = _('Failed to retrieve available VNF Catalog names: %s') % e
             LOG.error(msg)
 
+        try:
+            vim_list = api.tacker.vim_list(request)
+            available_choices_vims = [(vim['id'], vim['name']) for vim in
+                                      vim_list]
+
+        except Exception as e:
+            available_choices_vims = []
+            msg = _('Failed to retrieve available VIM names: %s') % e
+            LOG.error(msg)
+
         self.fields['vnfd_id'].choices = [('', _('Select a VNF Catalog Name'))
-                                          ]+available_choices
+                                          ]+available_choices_vnfd
+        self.fields['vim_id'].choices = [('',
+                                          _('Select a VIM Name'))
+                                         ]+available_choices_vims
 
     def clean(self):
-        data = super(AddService, self).clean()
+        data = super(DeployVNF, self).clean()
 
         param_file = data.get('param_file', None)
         param_raw = data.get('direct_input', None)
@@ -135,14 +152,27 @@ class AddService(forms.SelfHandlingForm):
         try:
             vnf_name = data['vnf_name']
             vnfd_id = data['vnfd_id']
+            vim_id = data['vim_id']
+            region_name = data['region_name']
+            param_val = data['param_values']
+            config_val = data['config_values']
             vnf_arg = {'vnf': {'vnfd_id': vnfd_id, 'name':  vnf_name,
-                               'attributes': {'param_values': data[
-                                   'param_values'], 'config': data[
-                                   'config_values']}}}
+                               'vim_id': vim_id}}
+            if region_name:
+                vnf_arg.setdefault('placement_attr', {})[
+                    region_name] = region_name
+            vnf_attr = vnf_arg['vnf'].setdefault('attributes', {})
+            if param_val:
+                vnf_attr['param_values'] = param_val
+            if config_val:
+                vnf_attr['config'] = config_val
+
             api.tacker.create_vnf(request, vnf_arg)
             messages.success(request,
-                             _('VNF %s create operation initiated.') % vnf_name)
+                             _('VNF %s create operation initiated.') %
+                             vnf_name)
             return True
         except Exception as e:
             exceptions.handle(request,
-                              _(e.message))
+                              _('Failed to create VNF: %s') %
+                              e.message)
